@@ -449,7 +449,7 @@ Emacs dired can't find files."
 
 (defun tramp-adb-handle-file-name-all-completions (filename directory)
   "Like `file-name-all-completions' for Tramp files."
-  (tramp-compat-ignore-error file-missing
+  (tramp-skeleton-file-name-all-completions filename directory
     (all-completions
      filename
      (with-parsed-tramp-file-name (expand-file-name directory) nil
@@ -464,17 +464,10 @@ Emacs dired can't find files."
 		(file-name-as-directory f)
 	      f))
 	  (with-current-buffer (tramp-get-buffer v)
-	    (delete-dups
-	     (append
-	      ;; On some file systems like "sdcard", "." and ".." are
-	      ;; not included.  We fix this by `delete-dups'.
-	      '("." "..")
-	      (delq
-	       nil
-	       (mapcar
-		(lambda (l)
-		  (and (not (string-match-p (rx bol (* blank) eol) l)) l))
-		(split-string (buffer-string) "\n"))))))))))))
+	    (mapcar
+	     (lambda (l)
+	       (and (not (string-match-p (rx bol (* blank) eol) l)) l))
+	     (split-string (buffer-string) "\n" 'omit)))))))))
 
 (defun tramp-adb-handle-file-local-copy (filename)
   "Like `file-local-copy' for Tramp files."
@@ -552,6 +545,8 @@ Emacs dired can't find files."
 	  (set-file-modes tmpfile (logior (or (file-modes tmpfile) 0) #o0600)))
 	(let (create-lockfiles)
           (write-region start end tmpfile append 'no-message))
+	;; Now, `last-coding-system-used' has the right value.  Remember it.
+	(setq coding-system-used last-coding-system-used)
 	(with-tramp-progress-reporter
 	    v 3 (format-message
 		 "Moving tmp file `%s' to `%s'" tmpfile filename)
