@@ -380,6 +380,9 @@ the result will be a local, non-Tramp, file name."
       ;; but to the root home directory.
       (when (tramp-string-empty-or-nil-p localname)
 	(setq localname "~"))
+      ;; Tilde expansion shall be possible also for quoted localname.
+      (when (string-prefix-p "~" (file-name-unquote localname))
+	(setq localname (file-name-unquote localname)))
       (unless (file-name-absolute-p localname)
 	(setq localname (format "~%s/%s" user localname)))
       (when (string-match
@@ -464,7 +467,7 @@ the result will be a local, non-Tramp, file name."
 
 (defun tramp-sudoedit-handle-file-name-all-completions (filename directory)
   "Like `file-name-all-completions' for Tramp files."
-  (tramp-compat-ignore-error file-missing
+  (tramp-skeleton-file-name-all-completions filename directory
     (all-completions
      filename
      (with-parsed-tramp-file-name (expand-file-name directory) nil
@@ -478,13 +481,11 @@ the result will be a local, non-Tramp, file name."
 	    (if (ignore-errors (file-directory-p (expand-file-name f directory)))
 		(file-name-as-directory f)
 	      f))
-	  (delq
-	   nil
-	   (mapcar
-	    (lambda (l) (and (not (string-match-p (rx bol (* blank) eol) l)) l))
-	    (split-string
-	     (tramp-get-buffer-string (tramp-get-connection-buffer v))
-	     "\n" 'omit)))))))))
+	  (mapcar
+	   (lambda (l) (and (not (string-match-p (rx bol (* blank) eol) l)) l))
+	   (split-string
+	    (tramp-get-buffer-string (tramp-get-connection-buffer v))
+	    "\n" 'omit))))))))
 
 (defun tramp-sudoedit-handle-file-readable-p (filename)
   "Like `file-readable-p' for Tramp files."
